#
# spec file for package python-oslo.cache
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-oslo.cache
Version:        2.3.0
Release:        bp155.2.11
Summary:        Cache storage for Openstack projects
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://launchpad.net/%{sname}
Source0:        https://files.pythonhosted.org/packages/source/o/oslo.cache/oslo.cache-2.3.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-dogpile.cache >= 0.6.2
BuildRequires:  python3-mock
BuildRequires:  python3-oslo.config >= 5.2.0
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslo.log >= 3.36.0
BuildRequires:  python3-oslo.utils >= 3.33.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr
BuildRequires:  python3-pymongo
BuildRequires:  python3-python-memcached
BuildRequires:  python3-six >= 1.11.0
BuildRequires:  python3-stestr
BuildArch:      noarch

%description
oslo.cache aims to provide a generic caching mechanism for OpenStack projects
by wrapping the dogpile.cache library. The dogpile.cache library provides
support memoization, key value storage and interfaces to common caching
backends such as Memcached.

%package -n python3-oslo.cache
Summary:        Cache storage for Openstack projects
Group:          Development/Languages/Python
Requires:       python3-dogpile.cache >= 0.6.2
Requires:       python3-oslo.config >= 5.2.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.log >= 3.36.0
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-python-memcached
Requires:       python3-six >= 1.11.0

%description -n python3-oslo.cache
oslo.cache aims to provide a generic caching mechanism for OpenStack projects
by wrapping the dogpile.cache library. The dogpile.cache library provides
support memoization, key value storage and interfaces to common caching
backends such as Memcached.

%package -n python-oslo.cache-doc
Summary:        Documentation for the OpenStack Oslo Cache library
Group:          Development/Languages/Python
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-sphinxcontrib-apidoc

%description -n python-oslo.cache-doc
Documentation for the OpenStack Oslo cache library.

%prep
%autosetup -p1 -n oslo.cache-2.3.0
%py_req_cleanup

%build
%{py3_build}

%install
%{py3_install}

# generate html docs
PBR_VERSION=2.3.0 %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%check
python3 -m stestr.cli run

%files -n python3-oslo.cache
%license LICENSE
%doc README.rst ChangeLog
%{python3_sitelib}/oslo_cache
%{python3_sitelib}/*.egg-info

%files -n python-oslo.cache-doc
%license LICENSE
%doc doc/build/html

%changelog
* Tue May 12 2020 cloud-devel@suse.de
- update to version 2.3.0
  - Add memcache_pool backend job
  - Update master for stable/train
  - Switch from python-memcached to pymemcache.
  - tox: Keeping going with docs
  - Update hacking for Python3
  - [ussuri][goal] Drop python 2.7 support and testing
  - remove outdated header
  - Fix pymemcache release note python package name
  - Remove dogpile kwarg test
  - Revert "Switch from python-memcached to pymemcache."
  - Update memcached configuration help text
  - trivial: Cleanup tox.ini
  - Use unittest.mock instead of third party mock
  - Ignore reno artifacts
  - Fix python2 syntaxe in doc
  - tox: Trivial cleanup
  - Imported Translations from Zanata
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 1.37.0
  - tox: Use the new hotness for constraints
  - Lower the memcache_socket_timeout to one second
  - Cap Bandit below 1.6.0 and update Sphinx requirement
  - Pass `flush_on_reconnect` to memcache pooled backend
  - add python 3.7 unit test job
  - Dropping the py35 testing
  - Avoid tox_install.sh for constraints support
  - Replace git.openstack.org URLs with opendev.org URLs.
  - OpenDev Migration Patch
  - Pass server_max_value_length to memcached client
  - Update hacking version
  - Fix lower-constraints
  - Add Python 3 Train unit tests
  - Update master for stable/stein
  - Remove stale comment in _memcache_pool
* Tue Jun 11 2019 cloud-devel@suse.de
- update to version 1.33.3
  - OpenDev Migration Patch
  - Update .gitreview for stable/stein
  - Pass `flush_on_reconnect` to memcache pooled backend
  - Update UPPER_CONSTRAINTS_FILE for stable/stein
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.33.2
  - Update mailinglist from dev to discuss
  - Drop expired connections before retrieving from the queue
  - fix tox python3 overrides
  - Config dict arguments.url must be a list
  - Update the requirements to match global-requirements for dogpile.cache
  - Switch to stestr
  - tox: Fix typo
  - uncap dogpile
  - Fix memcache pool client in monkey-patched environments
  - Imported Translations from Zanata
  - Always build universal wheels
  - Update reno for stable/rocky
  - Clean up .gitignore references to personal tools
  - Add release notes link to README
  - Don't quote {posargs} in tox.ini
  - Use template for lower-constraints
  - add lib-forward-testing-python3 test job
  - add python 3.6 unit test job
  - Only split url arg with memcache backend
  - import zuul job settings from project-config
  - fix dogpile.cache issue due to the new usage of decorate in the lib
* Wed Feb  6 2019 cloud-devel@suse.de
- update to version 1.30.3
  - Config dict arguments.url must be a list
  - Switch to stestr
  - Update .gitreview for stable/rocky
  - import zuul job settings from project-config
  - Only split url arg with memcache backend
* Sat Sep  1 2018 cloud-devel@suse.de
- update to version 1.30.1
  - Fix incompatible requirement in lower constraints
  - Remove stale pip-missing-reqs tox test
  - Update reno for stable/queens
  - Update links in README
  - Trivial: Update pypi url to new url
  - Change memcache_socket_timeout to a float
  - Imported Translations from Zanata
  - Avoid use of autodoc_tree_index_modules
  - Don't let tox_install.sh error if there is nothing to do
  - Clean old output before new doc builds
  - Switch pep8 job to python 3
  - Updated from global requirements
  - add lower-constraints job
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 1.28.0
  - Update the documentation link for doc migration
  - Follow the new PTI for document build
  - Update reno for stable/pike
  - Remove setting of version/release from releasenotes
  - Imported Translations from Zanata
  - Add more cache backend options
  - add bandit to pep8 job
  - Updated from global requirements
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.25.0
  - Change locations of docs for intersphinx
  - Remove log translations
  - Imported Translations from Zanata
  - Fix error in cache.configure_cache_region usage doc
  - etcd3 : get rid of ast_literal
  - Improve backend configuration help text
  - Remove unused/duplicated logging import
  - update the doc URLs
  - rearrange content to fit the new standard layout
  - Add kwarg function key generator
  - [Fix gate]Update test requirement
  - switch from oslosphinx to openstackdocstheme
  - pbr.version.VersionInfo needs package name (oslo.xyz and not oslo_xyz)
  - Replaces uuid.uuid4 with uuidutils.generate_uuid()
  - Update reno for stable/ocata
  - Switch to oslo_log
  - turn on warning-is-error in doc build
  - Check reStructuredText documents for common style issues.
  - Updated from global requirements
  - etcd3 driver for oslo.cache
  - Optimize the link address
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.17.0:
  - Imported Translations from Zanata
  - Update reno for stable/newton
  - Remove references to Python 3.4
  - Fix docstring for get_memoization_decorator
  - Add Constraints support
  - Show team and repo badges on README
  - Changed the home-page link
  - Enable release notes translation
  - TrivialFix: Remove default=None when set value in Config
  - Updated from global requirements
  - Add usage example to documentation
* Thu Sep  1 2016 tbechtold@suse.com
- update to version 1.14.0
  * Correct help text for backend option
  * Fix OpenStack capitalization
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 1.13.0
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 1.12.0
  * Fixup intersphinx docs
  * Use entrypoints for backends
  * Handle empty memcache pool corner case
  * Imported Translations from Zanata
  * Add Python 3.5 classifier and venv
  * Updated from global requirements
* Mon Jul  4 2016 tbechtold@suse.com
- update to 1.9.0:
  * Updated from global requirements
  * Add reno for releasenotes management
  * Trivial: ignore openstack/common in flake8 exclude list
  * Imported Translations from Zanata
  * Remove direct dependency on babel
  * If caching is globally disabled force dogpile to use the null backend
* Thu Jun  2 2016 tbechtold@suse.com
- use renderspec source service
- update spec from upstream
* Mon Apr  4 2016 tbechtold@suse.com
- update to 1.6.0:
  * Updated from global requirements
  * Update .gitreview for stable/mitaka
* Sun Mar 13 2016 dmueller@suse.com
- update to 1.5.0:
  * Updated from global requirements
* Thu Mar  3 2016 tbechtold@suse.com
- update to 1.4.0:
  * Updated from global requirements
  * Move some of these noisy logs to trace level
  * Revert "Use assertTrue/False instead of assertEqual(T/F)"
  * Update translation setup
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Delete python bytecode before every test run
  * Use assertTrue/False instead of assertEqual(T/F)
  * Updated from global requirements
  * Replace deprecated LOG.warn with LOG.warning
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Trival: Remove 'MANIFEST.in'
  * Updated from global requirements
  * Remove Python 2.6 classifier
  * Remove python 2.6 and cleanup tox.ini
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Export functions from __init__
- Adjust Requires according to requirements.txt
* Thu Oct 15 2015 dmueller@suse.com
- update to 0.8.0:
  * Make CacheIsolatingProxy public
  * Add shields.io version/downloads links/badges into README.rst
  * add auto-generated docs for config options
  * Change ignore-errors to ignore_errors
  * Updated from global requirements
* Thu Sep  3 2015 tbechtold@suse.com
- update to 0.7.0:
  * Updated from global requirements
  * Implement get/set/delete multiple keys for dictionary backend
* Thu Aug 27 2015 tbechtold@suse.com
- update to 0.6.0:
  * Move optional backend dependencies into setup.cfg [extras]
  * Ignore the .eggs/ directory
  * Remove remnants of noop backend registration
  * Updated from global requirements
  * Updated from global requirements
  * Setup translations
  * flake8 - remove unused rules and fix imports
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Remove NoOp cache from oslo.cache
- Adjust Requires according to requirements.txt
* Thu Jul 30 2015 tbechtold@suse.com
- Initial packaging
